# b3_greet

b3_greet is a simple Python library that provides greeting messages.

## Installation

```bash
pip install b3_greet
```

## Usage

```python
from b3_greet import say_hello

message = say_hello("Blue")
print(message)  # Outputs: Hello, Blue!
```

## License

[MIT License](./LICENSE)
